@@ -40,15 +40,17 @@ int levDistBounded(std::string a,
   if (b.empty()) { return(n); }
 
   // Strip common prefix
-  while (!a.empty() && !b.empty() && a.front() == b.front()) {
-    a.erase(0, 1);
-    b.erase(0, 1);
-  }
+  int bound = std::min(n, m), start;
+  for (start = 0; start < bound && a[start] == b[start]; ++start);
+  a = a.substr(start);
+  b = b.substr(start);
+  
   // Strip common suffix
   while (!a.empty() && !b.empty() && a.back() == b.back()) {
     a.pop_back();
     b.pop_back();
   }
+  
   // Use shorter string for column dimension to save memory
   if (b.length() > a.length()) { a.swap(b); } // ensures b is not longer than a
 
